@@ -78,21 +78,30 @@ static void               vd_parse_http_proxy     (const char* http_proxy, char
 #define hstrerror(e) ((const char*)NULL)
 #endif /*HAVE_HSTRERROR*/
 
-#if HAVE_STRNDUP
-/*OK*/
-#else
-#define strndup(s,n) strdup(s) 
-#endif /*HAVE_STRNDUP*/
-
-#ifndef VERSION
-#define VERSION "?.?"
-#endif /*VERSION*/
-
 #ifndef SA_LEN
 #define SA_LEN(x) (sizeof(struct sockaddr_in))
 #endif /*SA_LEN*/
 
 
+static char*
+gnuvd_strndup (const char *str, size_t n)
+{
+	char *dst;
+	
+	if (!str || n == 0)
+		return NULL;
+
+	dst = (char*)malloc(n + 1);
+	if (!dst)
+		return NULL;
+
+	memcpy (dst, str, n);
+	dst[n] = '\0';
+
+	return dst;
+}
+
+
 VDQuery*
 vd_query_new (const char *word, VDError *ex)
 {
@@ -386,8 +395,9 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 
 	int pos;
 	
-	static const char* word        = "<span class=\"g1v\">";
+	static const char* word        = "RESULTAAT (max 20 woorden)";
 	static const char* notfound    = "Geen resultaat.";
+	static const char* staatniet   = "gratis woordenboek";
 	static const char* metanav     = "class=\"metaNav\">";
 	static const char *href        = "href=";
 
@@ -395,8 +405,9 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 	assert (ex);
 	
 	pos = buffer_find (http_buffer, word, strlen(word));
+
 	if (pos <  buffer_end (http_buffer)) {
-		buffer_erase (http_buffer, 0, pos);
+		buffer_erase (http_buffer, 0, pos + strlen(word));
 	} else {
 		/* nothing was found or not available*/
 		pos = buffer_find (http_buffer, notfound, strlen(notfound));
@@ -407,6 +418,18 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 		return;
 	}
 
+	/* remove everything in lines with 'staat niet in het gratis woordenboek'
+	 *   until the end; ie. grep -v 'staat niet in gratis woordenboek
+	 */
+	pos = buffer_find (http_buffer, staatniet, strlen(staatniet));
+	if (pos <  buffer_end(http_buffer)) {
+		int sol = pos;
+		while (sol > buffer_begin(http_buffer) && buffer_at(http_buffer, sol) != '\n')
+			--sol;
+		buffer_erase (http_buffer, sol, buffer_end(http_buffer) - sol);
+		return; /* already done! */
+	}
+			
 	/* cut trailing stuff; we try metaNav first, then href, to be
 	*  safe against tiny changes in the webpage...
 	*/
@@ -418,7 +441,6 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 		buffer_erase (http_buffer, pos, buffer_end(http_buffer) - pos);
 	
 
-
 	/* find the last non-blank */
 	for (pos = buffer_end(http_buffer) - 1; pos >= buffer_begin(http_buffer); --pos) {
 		char c = buffer_at (http_buffer, pos);
@@ -437,8 +459,9 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 static void
 vd_parse_http_proxy (const char* http_proxy, char **host, char **port, VDError *ex)
 {
-	int i;
+  	int i;
 	int len;
+	char *c;
 
 	assert (host);
 	assert (port);
@@ -455,7 +478,7 @@ vd_parse_http_proxy (const char* http_proxy, char **host, char **port, VDError *
 
 	for (i = len - 1; i; --i) 
 		if (http_proxy[i] == ':') {
-			*port = strndup (http_proxy + i + 1, len - i - 1);
+			*port = gnuvd_strndup (http_proxy + i + 1, len - i - 1);
 			break;
 		}
 
@@ -467,11 +490,18 @@ vd_parse_http_proxy (const char* http_proxy, char **host, char **port, VDError *
 	
 	/* rest of string is host */
 	if (i >= 7 && strncmp (http_proxy, "http://", 7) == 0) 
-		*host = strndup (http_proxy + 7, i - 7);
+		*host = gnuvd_strndup (http_proxy + 7, i - 7);
 	else 
-		*host = strndup (http_proxy, i);
-	
-	*ex = *host ? VD_ERR_OK : VD_ERR_PROXY; 
+		*host = gnuvd_strndup (http_proxy, i);
+
+	/* don't include port */
+	if (host) {
+		c = strchr(*host, ':');
+		if (c) 
+			*c = '\0';
+	}		
+
+	*ex = *host ? VD_ERR_OK : VD_ERR_PROXY;
 }
 
 
