@@ -21,8 +21,6 @@
 #include <config.h>
 #endif /*HAVE_CONFIG*/
 
-#define _GNU_SOURCE /*for vasprintf*/
-
 #include <ctype.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -47,7 +45,7 @@
 #define S_KARS_MAX 10
 
 /* internal functions */
-static void show_results     (Buffer *results, int keep_entities);
+static int show_results     (Buffer *results, int keep_entities);
 static void help             (void);
 
 int
@@ -110,15 +108,17 @@ main (int argc, char* argv[])
 		return 1;	
 	} 
 
-	show_results (vd_query->_result_buffer, keep_entities);
+	if (!show_results (vd_query->_result_buffer, keep_entities))
+		fprintf (stderr, "'%s' was not found in the dictionary\n", 
+			 word); 
+
 	vd_query_destroy (vd_query);
 	
 	return 0;
 }
 
 
-
-static void
+static int
 show_results (Buffer* buffer, int keep_entities)
 {
 	BufferIterator j;
@@ -126,7 +126,8 @@ show_results (Buffer* buffer, int keep_entities)
 	int skip_spc     = 1;
 	char *data;
 	FILE *out        = stdout;
-	
+	int have_output   = 0;
+
 	/* output to PAGER or to STDOUT? */
 	if (isatty(fileno(stdin)) && isatty(fileno(stdout))) {
 		char *pager = getenv("PAGER");
@@ -171,22 +172,31 @@ show_results (Buffer* buffer, int keep_entities)
 		/* append one character */
 		buffer_append (output, buffer_data_pos(buffer, j), 1);
         }
-	/* strip trailing space */
-	for (j = buffer_end(output) - 1; j >= buffer_begin(output); --j) 
-		if (isalnum(buffer_at(output, j)))
-			break;
-	if (j >= buffer_begin(output))
-		buffer_erase (output, j + 1, buffer_end(output) - j - 1);
 
-	data = strndup (buffer_data(output), buffer_length(output));
-	fprintf (out, "%s\n", data);
-	free (data);
-	
-	/* if we were outputing to PAGER, close it */
-	if (out != stdout) {
-		fflush (out);
-		pclose (out);
-	}
+	if (buffer_length(output) != 0) {
+		/* strip trailing space */
+		for (j = buffer_end(output) - 1; j >= buffer_begin(output); --j) 
+			if (isalnum(buffer_at(output, j)))
+				break;
+		if (j >= buffer_begin(output))
+			buffer_erase (output, j + 1, buffer_end(output) - j - 1);
+		
+		data = buffer_data_to_string (output);
+		fprintf (out, "%s\n", data);
+		free (data);
+		
+		/* if we were outputing to PAGER, close it */
+		if (out != stdout) {
+			fflush (out);
+			pclose (out);
+		}
+		have_output = 1;
+	} else
+		have_output = 0;
+
+	buffer_destroy (output);
+
+	return have_output;
 }
 
 static void
